====================
My First PH3 Package
====================


.. image:: https://img.shields.io/pypi/v/my-first-ph3-package.svg
        :target: https://pypi.python.org/pypi/my-first-ph3-package
        :alt: PyPI Status

.. image:: https://github.com/balouf/my-first-ph3-package/actions/workflows/build.yml/badge.svg?branch=main
        :target: https://github.com/balouf/my-first-ph3-package/actions?query=workflow%3Abuild
        :alt: Build Status

.. image:: https://github.com/balouf/my-first-ph3-package/actions/workflows/docs.yml/badge.svg?branch=main
        :target: https://github.com/balouf/my-first-ph3-package/actions?query=workflow%3Adocs
        :alt: Documentation Status

.. image:: https://img.shields.io/github/license/balouf/my-first-ph3-package
        :target: image:: https://img.shields.io/github/license/balouf/my-first-ph3-package
        :alt: License

.. image:: https://codecov.io/gh/balouf/my-first-ph3-package/branch/main/graphs/badge.svg
        :target: https://codecov.io/gh/balouf/my-first-ph3-package/tree/main
        :alt: Code Coverage

PH3 packages are quick to make!


* Free software: MIT license
* Documentation: https://balouf.github.io/my-first-ph3-package/.


--------
Features
--------

* TODO

-------
Credits
-------

This package was created with Cookiecutter_ and the `package-helper-3`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`package-helper-3`: https://balouf.github.io/package-helper-3/
